@@ -1,4 +1,4 @@
-# default methods, glm (almost default)
+# Arguments passed to or from other methods. For instance, when default methods, glm (almost default)
 
 #################### .default ----------------------
 
@@ -44,151 +44,6 @@
 #'   method for use inside rmarkdown files,
 #'   [`print_md()`][print_md.parameters_model].
 #'
-#' @section Confidence intervals and approximation of degrees of freedom:
-#' There are different ways of approximating the degrees of freedom depending
-#' on different assumptions about the nature of the model and its sampling
-#' distribution. The `ci_method` modulates the method for computing degrees
-#' of freedom (df) that are used to calculate confidence intervals (CI) and the
-#' related p-values. Following options are allowed, depending on the model
-#' class:
-#'
-#' **Classical methods:**
-#'
-#' Classical inference is generally based on the **Wald method**.
-#' The Wald approach to inference computes a test statistic by dividing the
-#' parameter estimate by its standard error (Coefficient / SE),
-#' then comparing this statistic against a t- or normal distribution.
-#' This approach can be used to compute CIs and p-values.
-#'
-#' `"wald"`
-#' - Applies to *non-Bayesian models*
-#' - For *linear models*, CIs computed using the Wald method (SE and a *t-distribution with residual df*)
-#' - For *linear models*, p-values computed using the Wald method with a *t-distribution with residual df*
-#' - For other models, CIs computed using the Wald method (SE and a *normal distribution*)
-#' - For other models, p-values computed using the Wald method with a *normal distribution*
-#'
-#' `"normal"`
-#' - Applies to *non-Bayesian models*
-#' - Compute Wald CIs and p values, but always use a normal distribution
-#' - CIs computed using the Wald method (SE and a *normal distribution*)
-#' - p-values computed using the Wald method with a *normal distribution*
-#'
-#' `"residual"`
-#' - Applies to *non-Bayesian models*
-#' - Compute Wald CIs and p values, but always use a *t-distribution with residual df* when possible
-#' - CIs computed using the Wald method (SE and a *t-distribution with residual df*)
-#' - p-values computed using the Wald method with a *t-distribution with residual df*
-#' - If the residual df for a model cannot be determined, a normal distribution is used instead
-#'
-#' **Methods for mixed models:**
-#'
-#' Compared to fixed effects (or single-level) models, determining appropriate
-#' df for Wald-based inference in mixed models is more difficult.
-#' See [the R GLMM FAQ](https://bbolker.github.io/mixedmodels-misc/glmmFAQ.html#what-are-the-p-values-listed-by-summaryglmerfit-etc.-are-they-reliable)
-#' for a discussion.
-#'
-#' Several approximate methods for computing df are available, but you should
-#' also consider instead using profile likelihood (`"profile"`) or bootstrap ("`boot"`)
-#' CIs and p-values instead.
-#'
-#' `"satterthwaite"`
-#' - Applies to *linear mixed models*
-#' - CIs computed using the Wald method (SE and a *t-distribution with Satterthwaite df*)
-#' - p-values computed using the Wald method with a *t-distribution with Satterthwaite df*
-#'
-#' `"kenward"`
-#' - Applies to *linear mixed models*
-#' - CIs computed using the Wald method (*Kenward-Roger SE* and a *t-distribution with Kenward-Roger df*)
-#' - p-values computed using the Wald method with a *Kenward-Roger SE and t-distribution with Kenward-Roger df*
-#'
-#' `"ml1"`
-#' - Applies to *linear mixed models*
-#' - CIs computed using the Wald method (SE and a *t-distribution with m-l-1 approximated df*)
-#' - p-values computed using the Wald method with a *t-distribution with m-l-1 approximated df*
-#' - See [`ci_ml1()`]
-#'
-#' `"betwithin"`
-#' - Applies to *linear mixed models* and *generalized linear mixed models*
-#' - CIs computed using the Wald method (SE and a *t-distribution with between-within df*)
-#' - p-values computed using the Wald method with a *t-distribution with between-within df*
-#' - See [`ci_betwithin()`]
-#'
-#' **Likelihood-based methods:**
-#'
-#' Likelihood-based inference is based on comparing the likelihood for the
-#' maximum-likelihood estimate to the the likelihood for models with one or more
-#' parameter values changed (e.g., set to zero or a range of alternative values).
-#' Likelihood ratios for the maximum-likelihood and alternative models are compared
-#' to a \eqn{\chi}-squared distribution to compute CIs and p-values.
-#'
-#' `"profile"`
-#' - Applies to *non-Bayesian models* of class `glm`, `polr` or `glmmTMB`
-#' - CIs computed by *profiling the likelihood curve for a parameter*,
-#'   using linear interpolation to find where likelihood ratio equals a critical value
-#' - p-values computed using the Wald method with a *normal-distribution)*
-#'   (note: this might change in a future update!)
-#'
-#' `"uniroot"`
-#' - Applies to *non-Bayesian models* of class `glmmTMB`
-#' - CIs computed by *profiling the likelihood curve for a parameter*,
-#'   using root finding to find where likelihood ratio equals a critical value;
-#' - p-values computed using the Wald method with a *normal-distribution)*
-#'   (note: this might change in a future update!)
-#'
-#' **Methods for bootstrapped or Bayesian models:**
-#'
-#' Bootstrap-based inference is based on **resampling** and refitting the model
-#' to the resampled datasets. The distribution of parameter estimates across resampled
-#' datasets is used to approximate the parameter's sampling distribution.
-#' Depending on the type of model, several different methods for bootstrapping
-#' and constructing CIs and p-values from the bootstrap distribution are available.
-#'
-#' For Bayesian models, inference is based on drawing samples from the model posterior distribution.
-#'
-#' `"quantile"`
-#' - Applies to *all models (including Bayesian models)*
-#' - For non-Bayesian models, only applies if `bootstrap = TRUE`
-#' - CIs computed as *equal tailed intervals* using the quantiles of the bootstrap or posterior samples
-#' - p-values are based on the *probability of direction*
-#' - See [`bayestestR::eti()`]
-#'
-#' `"eti"`
-#' - Same as `"quantile"`
-#'
-#' `"hdi"`
-#' - Applies to *all models (including Bayesian models)*
-#' - For non-Bayesian models, only applies if `bootstrap = TRUE`
-#' - CIs computed as *highest density intervals* for the bootstrap or posterior samples
-#' - p-values are based on the *probability of direction*
-#' - See [`bayestestR::hdi()`]
-#'
-#' `"bci"`
-#' - Applies to *all models (including Bayesian models)*
-#' - For non-Bayesian models, only applies if `bootstrap = TRUE`
-#' - CIs computed as *bias corrected and accelerated intervals* for the bootstrap or posterior samples
-#' - p-values are based on the *probability of direction*
-#' - See [`bayestestR::bci()`]
-#'
-#' `"bcai"`
-#' - Same as `"bci"`
-#'
-#' `"si"`
-#' - Applies to *Bayesian models* with proper priors
-#' - CIs computed as *support intervals* comparing the posterior samples against the prior samples
-#' - p-values are based on the *probability of direction*
-#' - See [`bayestestR::si()`]
-#'
-#' `"boot"`
-#' - Applies to *non-Bayesian models* of class `merMod`
-#' - CIs computed using *parametric bootstrapping* (simulating data from the fitted model)
-#' - p-values computed using the Wald method with a *normal-distribution)*
-#'   (note: this might change in a future update!)
-#'
-#' For all iteration-based methods other than `"boot"`
-#' (`"hdi"`, `"quantile"`, `"ci"`, `"eti"`, `"si"`, `"bci"`, `"bcai"`),
-#' p-values are based on the probability of direction ([`bayestestR::p_direction()`]),
-#' which is converted into a p-value using [`bayestestR::pd_to_p()`].
-#'
 #' @section Standardization of model coefficients:
 #' Standardization is based on [effectsize::standardize_parameters()]. In case
 #' of `standardize = "refit"`, the data used to fit the model will be
@@ -199,7 +54,10 @@
 #' packages or other software packages (like SPSS). To mimic behaviour of SPSS
 #' or packages such as \pkg{lm.beta}, use `standardize = "basic"`.
 #'
-#' @section Standardization Methods:
+#' @section
+#'
+#' Standardization Methods:
+#'
 #' - **refit**: This method is based on a complete model re-fit with a
 #' standardized version of the data. Hence, this method is equal to
 #' standardizing the variables before fitting the model. It is the "purest" and
@@ -210,11 +68,12 @@
 #' The `robust` (default to `FALSE`) argument enables a robust standardization
 #' of data, i.e., based on the `median` and `MAD` instead of the `mean` and
 #' `SD`. **See [standardize()] for more details.**
-#'   - **Note** that `standardize_parameters(method = "refit")` may not return
-#'   the same results as fitting a model on data that has been standardized with
-#'   `standardize()`; `standardize_parameters()` used the data used by the model
-#'   fitting function, which might not be same data if there are missing values.
-#'   see the `remove_na` argument in `standardize()`.
+#' **Note** that `standardize_parameters(method = "refit")` may not return
+#' the same results as fitting a model on data that has been standardized with
+#' `standardize()`; `standardize_parameters()` used the data used by the model
+#' fitting function, which might not be same data if there are missing values.
+#' see the `remove_na` argument in `standardize()`.
+#'
 #' - **posthoc**: Post-hoc standardization of the parameters, aiming at
 #' emulating the results obtained by "refit" without refitting the model. The
 #' coefficients are divided by the standard deviation (or MAD if `robust`) of
@@ -226,12 +85,14 @@
 #' variables or factors, so the coefficients are still related to changes in
 #' levels. This method is not accurate and tend to give aberrant results when
 #' interactions are specified.
+#'
 #' - **basic**: This method is similar to `method = "posthoc"`, but treats all
 #' variables as continuous: it also scales the coefficient by the standard
 #' deviation of model's matrix' parameter of factors levels (transformed to
 #' integers) or binary predictors. Although being inappropriate for these cases,
 #' this method is the one implemented by default in other software packages,
 #' such as [lm.beta::lm.beta()].
+#'
 #' - **smart** (Standardization of Model's parameters with Adjustment,
 #' Reconnaissance and Transformation - *experimental*): Similar to `method =
 #' "posthoc"` in that it does not involve model refitting. The difference is
@@ -241,6 +102,7 @@
 #' vs. A will be scaled by the variance of the response at the intercept only.
 #' As a results, the coefficients for effects of factors are similar to a Glass'
 #' delta.
+#'
 #' - **pseudo** (*for 2-level (G)LMMs only*): In this (post-hoc) method, the
 #' response and the predictor are standardized based on the level of prediction
 #' (levels are detected with [performance::check_heterogeneity_bias()]): Predictors
@@ -260,11 +122,149 @@
 #' think that `df_error` is the most generic label for these degrees of
 #' freedom.
 #'
+#' @section Confidence intervals and approximation of degrees of freedom:
+#' There are different ways of approximating the degrees of freedom depending
+#' on different assumptions about the nature of the model and its sampling
+#' distribution. The `ci_method` argument modulates the method for computing degrees
+#' of freedom (df) that are used to calculate confidence intervals (CI) and the
+#' related p-values. Following options are allowed, depending on the model
+#' class:
+#'
+#' **Classical methods:**
+#'
+#' Classical inference is generally based on the **Wald method**.
+#' The Wald approach to inference computes a test statistic by dividing the
+#' parameter estimate by its standard error (Coefficient / SE),
+#' then comparing this statistic against a t- or normal distribution.
+#' This approach can be used to compute CIs and p-values.
+#'
+#' `"wald"`:
+#' - Applies to *non-Bayesian models*. For *linear models*, CIs
+#'   computed using the Wald method (SE and a *t-distribution with residual df*);
+#'   p-values computed using the Wald method with a *t-distribution with residual df*.
+#'   For other models, CIs computed using the Wald method (SE and a *normal distribution*);
+#'   p-values computed using the Wald method with a *normal distribution*.
+#'
+#' `"normal"`
+#' - Applies to *non-Bayesian models*. Compute Wald CIs and p-values,
+#'   but always use a normal distribution.
+#'
+#' `"residual"`
+#' - Applies to *non-Bayesian models*. Compute Wald CIs and p-values,
+#'   but always use a *t-distribution with residual df* when possible. If the
+#'   residual df for a model cannot be determined, a normal distribution is
+#'   used instead.
+#'
+#' **Methods for mixed models:**
+#'
+#' Compared to fixed effects (or single-level) models, determining appropriate
+#' df for Wald-based inference in mixed models is more difficult.
+#' See [the R GLMM FAQ](https://bbolker.github.io/mixedmodels-misc/glmmFAQ.html#what-are-the-p-values-listed-by-summaryglmerfit-etc.-are-they-reliable)
+#' for a discussion.
+#'
+#' Several approximate methods for computing df are available, but you should
+#' also consider instead using profile likelihood (`"profile"`) or bootstrap ("`boot"`)
+#' CIs and p-values instead.
+#'
+#' `"satterthwaite"`
+#' - Applies to *linear mixed models*. CIs computed using the
+#'   Wald method (SE and a *t-distribution with Satterthwaite df*); p-values
+#'   computed using the Wald method with a *t-distribution with Satterthwaite df*.
+#'
+#' `"kenward"`
+#' - Applies to *linear mixed models*. CIs computed using the Wald
+#'   method (*Kenward-Roger SE* and a *t-distribution with Kenward-Roger df*);
+#'   p-values computed using the Wald method with *Kenward-Roger SE and t-distribution with Kenward-Roger df*.
+#'
+#' `"ml1"`
+#' - Applies to *linear mixed models*. CIs computed using the Wald
+#'   method (SE and a *t-distribution with m-l-1 approximated df*); p-values
+#'   computed using the Wald method with a *t-distribution with m-l-1 approximated df*.
+#'   See [`ci_ml1()`].
+#'
+#' `"betwithin"`
+#' - Applies to *linear mixed models* and *generalized linear mixed models*.
+#'   CIs computed using the Wald method (SE and a *t-distribution with between-within df*);
+#'   p-values computed using the Wald method with a *t-distribution with between-within df*.
+#'   See [`ci_betwithin()`].
+#'
+#' **Likelihood-based methods:**
+#'
+#' Likelihood-based inference is based on comparing the likelihood for the
+#' maximum-likelihood estimate to the the likelihood for models with one or more
+#' parameter values changed (e.g., set to zero or a range of alternative values).
+#' Likelihood ratios for the maximum-likelihood and alternative models are compared
+#' to a \eqn{\chi}-squared distribution to compute CIs and p-values.
+#'
+#' `"profile"`
+#' - Applies to *non-Bayesian models* of class `glm`, `polr` or `glmmTMB`.
+#'   CIs computed by *profiling the likelihood curve for a parameter*, using
+#'   linear interpolation to find where likelihood ratio equals a critical value;
+#'   p-values computed using the Wald method with a *normal-distribution* (note:
+#'   this might change in a future update!)
+#'
+#' `"uniroot"`
+#' - Applies to *non-Bayesian models* of class `glmmTMB`. CIs
+#'   computed by *profiling the likelihood curve for a parameter*, using root
+#'   finding to find where likelihood ratio equals a critical value; p-values
+#'   computed using the Wald method with a *normal-distribution* (note: this
+#'   might change in a future update!)
+#'
+#' **Methods for bootstrapped or Bayesian models:**
+#'
+#' Bootstrap-based inference is based on **resampling** and refitting the model
+#' to the resampled datasets. The distribution of parameter estimates across
+#' resampled datasets is used to approximate the parameter's sampling
+#' distribution. Depending on the type of model, several different methods for
+#' bootstrapping and constructing CIs and p-values from the bootstrap
+#' distribution are available.
+#'
+#' For Bayesian models, inference is based on drawing samples from the model
+#' posterior distribution.
+#'
+#' `"quantile"` (or `"eti"`)
+#' - Applies to *all models (including Bayesian models)*.
+#'   For non-Bayesian models, only applies if `bootstrap = TRUE`. CIs computed
+#'   as *equal tailed intervals* using the quantiles of the bootstrap or
+#'   posterior samples; p-values are based on the *probability of direction*.
+#'   See [`bayestestR::eti()`].
+#'
+#' `"hdi"`
+#' - Applies to *all models (including Bayesian models)*. For non-Bayesian
+#'   models, only applies if `bootstrap = TRUE`. CIs computed as *highest density intervals*
+#'   for the bootstrap or posterior samples; p-values are based on the *probability of direction*.
+#'   See [`bayestestR::hdi()`].
+#'
+#' `"bci"` (or `"bcai"`)
+#' - Applies to *all models (including Bayesian models)*.
+#'   For non-Bayesian models, only applies if `bootstrap = TRUE`. CIs computed
+#'   as *bias corrected and accelerated intervals* for the bootstrap or
+#'   posterior samples; p-values are based on the *probability of direction*.
+#'   See [`bayestestR::bci()`].
+#'
+#' `"si"`
+#' - Applies to *Bayesian models* with proper priors. CIs computed as
+#'   *support intervals* comparing the posterior samples against the prior samples;
+#'   p-values are based on the *probability of direction*. See [`bayestestR::si()`].
+#'
+#' `"boot"`
+#' - Applies to *non-Bayesian models* of class `merMod`. CIs computed
+#'   using *parametric bootstrapping* (simulating data from the fitted model);
+#'   p-values computed using the Wald method with a *normal-distribution)*
+#'   (note: this might change in a future update!).
+#'
+#' For all iteration-based methods other than `"boot"`
+#' (`"hdi"`, `"quantile"`, `"ci"`, `"eti"`, `"si"`, `"bci"`, `"bcai"`),
+#' p-values are based on the probability of direction ([`bayestestR::p_direction()`]),
+#' which is converted into a p-value using [`bayestestR::pd_to_p()`].
+#'
 #' @inheritSection format_parameters Interpretation of Interaction Terms
 #'
 #' @references
+#'
 #'   - Hoffman, L. (2015). Longitudinal analysis: Modeling within-person
 #'   fluctuation and change. Routledge.
+#'
 #'   - Neter, J., Wasserman, W., & Kutner, M. H. (1989). Applied linear
 #'   regression models.
 #'
@@ -314,10 +314,10 @@ parameters <- model_parameters
 #'   factors), which may be a different behaviour compared to other R packages
 #'   (such as \pkg{lm.beta}) or other software packages (like SPSS). to mimic
 #'   such behaviours, either use `standardize="basic"` or standardize the data
-#'   with `effectsize::standardize(force=TRUE)` *before* fitting the model.
+#'   with `datawizard::standardize(force=TRUE)` *before* fitting the model.
 #'   - For mixed models, when using methods other than `"refit"`, only the fixed
 #'   effects will be returned.
-#'   - Robust estimation (i.e. `robust=TRUE`) of standardized parameters only
+#'   - Robust estimation (i.e., `vcov` set to a value other than `NULL`) of standardized parameters only
 #'   works when `standardize="refit"`.
 #' @param exponentiate Logical, indicating whether or not to exponentiate the
 #'   the coefficients (and related confidence intervals). This is typical for
@@ -330,13 +330,6 @@ parameters <- model_parameters
 #'   captures this uncertainty. For `compare_parameters()`,
 #'   `exponentiate = "nongaussian"` will only exponentiate coefficients
 #'   from non-Gaussian families.
-#' @param robust Logical, if `TRUE`, robust standard errors are calculated
-#'   (if possible), and confidence intervals and p-values are based on these
-#'   robust standard errors. Additional arguments like `vcov_estimation` or
-#'   `vcov_type` are passed down to other methods, see
-#'   [`standard_error_robust()`][standard_error_robust] for details
-#'   and [this vignette](https://easystats.github.io/parameters/articles/model_parameters_robust.html)
-#'   for working examples.
 #' @param component Model component for which parameters should be shown. May be
 #'   one of `"conditional"`, `"precision"` (\pkg{betareg}),
 #'   `"scale"` (\pkg{ordinal}), `"extra"` (\pkg{glmx}),
@@ -360,13 +353,13 @@ parameters <- model_parameters
 #' @param summary Logical, if `TRUE`, prints summary information about the
 #'   model (model formula, number of observations, residual standard deviation
 #'   and more).
-#' @param keep,drop Character containing a regular expression pattern that
+#' @param keep Character containing a regular expression pattern that
 #'   describes the parameters that should be included (for `keep`) or excluded
 #'   (for `drop`) in the returned data frame. `keep` may also be a
 #'   named list of regular expressions. All non-matching parameters will be
 #'   removed from the output. If `keep` is a character vector, every parameter
 #'   name in the *"Parameter"* column that matches the regular expression in
-#'   `parameters` will be selected from the returned data frame (and vice versa,
+#'   `keep` will be selected from the returned data frame (and vice versa,
 #'   all parameter names matching `drop` will be excluded). Furthermore, if
 #'   `keep` has more than one element, these will be merged with an `OR`
 #'   operator into a regular expression pattern like this: `"(one|two|three)"`.
@@ -379,8 +372,10 @@ parameters <- model_parameters
 #'   frame, which can be different from how they are printed. Inspect the
 #'   `$Parameter` column of the parameters table to get the exact parameter
 #'   names.
+#' @param drop See `keep`.
 #' @param parameters Deprecated, alias for `keep`.
 #' @param verbose Toggle warnings and messages.
+#' @inheritParams standard_error
 #' @param ... Arguments passed to or from other methods. For instance, when
 #'   `bootstrap = TRUE`, arguments like `type` or `parallel` are
 #'   passed down to `bootstrap_model()`, and arguments like `ci_method`
@@ -403,10 +398,16 @@ parameters <- model_parameters
 #' # standardized parameters
 #' model_parameters(model, standardize = "refit")
 #'
+#' # robust, heteroskedasticity-consistent standard errors
+#' model_parameters(model, vcov = "HC3")
+#'
+#' model_parameters(model,
+#'                  vcov = "vcovCL",
+#'                  vcov_args = list(cluster = mtcars$cyl))
+#'
 #' # different p-value style in output
 #' model_parameters(model, p_digits = 5)
 #' model_parameters(model, digits = 3, ci_digits = 4, p_digits = "scientific")
-#'
 #' \donttest{
 #' # logistic regression model
 #' model <- glm(vs ~ wt + cyl, data = mtcars, family = "binomial")
@@ -424,14 +425,18 @@ model_parameters.default <- function(model,
                                      iterations = 1000,
                                      standardize = NULL,
                                      exponentiate = FALSE,
-                                     robust = FALSE,
                                      p_adjust = NULL,
-                                     summary = FALSE,
+                                     summary = getOption("parameters_summary", FALSE),
                                      keep = NULL,
                                      drop = NULL,
                                      parameters = keep,
                                      verbose = TRUE,
+                                     vcov = NULL,
+                                     vcov_args = NULL,
                                      ...) {
+
+  dots <- list(...)
+
   out <- tryCatch(
     {
       .model_parameters_generic(
@@ -443,11 +448,12 @@ model_parameters.default <- function(model,
         merge_by = "Parameter",
         standardize = standardize,
         exponentiate = exponentiate,
-        robust = robust,
         p_adjust = p_adjust,
         summary = summary,
         keep_parameters = keep,
         drop_parameters = drop,
+        vcov = vcov,
+        vcov_args = vcov_args,
         verbose = verbose,
         ...
       )
@@ -483,7 +489,6 @@ model_parameters.default <- function(model,
                                       exponentiate = FALSE,
                                       effects = "fixed",
                                       component = "conditional",
-                                      robust = FALSE,
                                       ci_method = NULL,
                                       p_adjust = NULL,
                                       summary = FALSE,
@@ -491,11 +496,16 @@ model_parameters.default <- function(model,
                                       drop_parameters = NULL,
                                       verbose = TRUE,
                                       df_method = ci_method,
+                                      vcov = NULL,
+                                      vcov_args = NULL,
                                       ...) {
 
+
+  dots <- list(...)
+
   ## TODO remove later
   if (!missing(df_method) && !identical(ci_method, df_method)) {
-    message(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."))
+    warning(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."), call. = FALSE)
     ci_method <- df_method
   }
 
@@ -506,34 +516,36 @@ model_parameters.default <- function(model,
       ci_method <- "quantile"
     }
 
-    params <- bootstrap_parameters(
+    args <- list(
       model,
       iterations = iterations,
       ci = ci,
-      ci_method = ci_method,
-      ...
-    )
+      ci_method = ci_method)
+    args <- c(args, dots)
+    params <- do.call("bootstrap_parameters", args)
   } else {
     # set default method for CI
     if (is.null(ci_method) || missing(ci_method)) {
       ci_method <- "wald"
     }
 
-    params <- .extract_parameters_generic(
+    args <- list(
       model,
       ci = ci,
       component = component,
       merge_by = merge_by,
       standardize = standardize,
       effects = effects,
-      robust = robust,
       ci_method = ci_method,
       p_adjust = p_adjust,
       keep_parameters = keep_parameters,
       drop_parameters = drop_parameters,
       verbose = verbose,
-      ...
+      vcov = vcov,
+      vcov_args = vcov_args
     )
+    args <- c(args, dots)
+    params <- do.call(".extract_parameters_generic", args)
   }
 
   if (isTRUE(exponentiate) || identical(exponentiate, "nongaussian")) {
@@ -549,7 +561,6 @@ model_parameters.default <- function(model,
     iterations,
     ci_method = ci_method,
     p_adjust = p_adjust,
-    robust = robust,
     summary = summary,
     verbose = verbose,
     ...
@@ -574,13 +585,17 @@ model_parameters.glm <- function(model,
                                  iterations = 1000,
                                  standardize = NULL,
                                  exponentiate = FALSE,
-                                 robust = FALSE,
                                  p_adjust = NULL,
-                                 summary = FALSE,
-                                 verbose = TRUE,
+                                 summary = getOption("parameters_summary", FALSE),
                                  df_method = ci_method,
+                                 vcov = NULL,
+                                 vcov_args = NULL,
+                                 verbose = TRUE,
                                  ...) {
 
+
+  dots <- list(...)
+
   # set default
   if (is.null(ci_method)) {
     ci_method <- ifelse(isTRUE(bootstrap), "quantile", "profile")
@@ -588,7 +603,7 @@ model_parameters.glm <- function(model,
 
   ## TODO remove later
   if (!missing(df_method) && !identical(ci_method, df_method)) {
-    message(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."))
+    warning(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."), call. = FALSE)
     ci_method <- df_method
   }
 
@@ -596,7 +611,7 @@ model_parameters.glm <- function(model,
     message(insight::format_message("Profiled confidence intervals may take longer time to compute. Use 'ci_method=\"wald\"' for faster computation of CIs."))
   }
 
-  out <- .model_parameters_generic(
+  args <- list(
     model = model,
     ci = ci,
     ci_method = ci_method,
@@ -605,11 +620,13 @@ model_parameters.glm <- function(model,
     merge_by = "Parameter",
     standardize = standardize,
     exponentiate = exponentiate,
-    robust = robust,
     p_adjust = p_adjust,
     summary = summary,
-    ...
+    vcov = vcov,
+    vcov_args = vcov_args
   )
+  args <- c(args, dots)
+  out <- do.call(".model_parameters_generic", args)
 
   attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
   out
