@@ -35,17 +35,17 @@ model_parameters.zcpglm <- function(model,
                                     component = c("all", "conditional", "zi", "zero_inflated"),
                                     standardize = NULL,
                                     exponentiate = FALSE,
-                                    robust = FALSE,
                                     p_adjust = NULL,
                                     keep = NULL,
                                     drop = NULL,
                                     parameters = keep,
+                                    summary = getOption("parameters_summary", FALSE),
                                     verbose = TRUE,
                                     ...) {
   component <- match.arg(component)
 
   # fix argument, if model has no zi-part
-  if (!insight::model_info(model)$is_zero_inflated && component != "conditional") {
+  if (!insight::model_info(model, verbose = FALSE)$is_zero_inflated && component != "conditional") {
     component <- "conditional"
   }
 
@@ -59,10 +59,10 @@ model_parameters.zcpglm <- function(model,
       ci = ci,
       component = component,
       standardize = standardize,
-      robust = robust,
       p_adjust = p_adjust,
       keep_parameters = keep,
       drop_parameters = drop,
+      verbose = verbose,
       ...
     )
   }
@@ -78,6 +78,7 @@ model_parameters.zcpglm <- function(model,
     ci,
     exponentiate,
     p_adjust = p_adjust,
+    summary = summary,
     verbose = verbose,
     ...
   )
@@ -229,11 +230,12 @@ model_parameters.cpglmm <- function(model,
                                     p_adjust = NULL,
                                     verbose = TRUE,
                                     df_method = ci_method,
+                                    include_sigma = FALSE,
                                     ...) {
 
   ## TODO remove later
   if (!missing(df_method) && !identical(ci_method, df_method)) {
-    message(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."))
+    warning(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."), call. = FALSE)
     ci_method <- df_method
   }
 
@@ -258,10 +260,10 @@ model_parameters.cpglmm <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     effects = effects,
-    robust = FALSE,
     p_adjust = p_adjust,
     group_level = group_level,
     ci_method = ci_method,
+    include_sigma = include_sigma,
     ...
   )
 
