@@ -1,6 +1,3 @@
-
-#' @importFrom insight print_color
-#' @importFrom stats qt
 #' @export
 ci.effectsize_std_params <- function(x, ci = .95, verbose = TRUE, ...) {
   se <- attr(x, "standard_error")
@@ -44,7 +41,7 @@ ci.effectsize_std_params <- function(x, ci = .95, verbose = TRUE, ...) {
     )
   })
 
-  .remove_backticks_from_parameter_names(do.call(rbind, out))
+  insight::text_remove_backticks(do.call(rbind, out), verbose = FALSE)
 }
 
 
