@@ -16,20 +16,21 @@ model_parameters.glmmTMB <- function(model,
                                      group_level = FALSE,
                                      standardize = NULL,
                                      exponentiate = FALSE,
-                                     ci_method = NULL,
+                                     ci_method = "wald",
                                      p_adjust = NULL,
                                      wb_component = TRUE,
-                                     summary = FALSE,
+                                     summary = getOption("parameters_mixed_summary", FALSE),
                                      keep = NULL,
                                      drop = NULL,
                                      parameters = keep,
                                      verbose = TRUE,
                                      df_method = ci_method,
+                                     include_sigma = FALSE,
                                      ...) {
 
   ## TODO remove later
   if (!missing(df_method) && !identical(ci_method, df_method)) {
-    message(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."))
+    warning(insight::format_message("Argument 'df_method' is deprecated. Please use 'ci_method' instead."), call. = FALSE)
     ci_method <- df_method
   }
 
@@ -50,7 +51,7 @@ model_parameters.glmmTMB <- function(model,
 
   # fix argument, if model has only conditional component
   cs <- stats::coef(summary(model))
-  has_zeroinf <- insight::model_info(model)$is_zero_inflated
+  has_zeroinf <- insight::model_info(model, verbose = FALSE)$is_zero_inflated
   has_disp <- is.list(cs) && !is.null(cs$disp)
 
   if (!has_zeroinf && !has_disp && component != "conditional") {
@@ -58,6 +59,7 @@ model_parameters.glmmTMB <- function(model,
   }
 
   params <- params_random <- params_variance <- NULL
+  dispersion_param <- FALSE
 
   if (effects %in% c("fixed", "all")) {
     # Processing
@@ -80,25 +82,39 @@ model_parameters.glmmTMB <- function(model,
         ci = ci,
         component = component,
         standardize = standardize,
-        robust = FALSE,
         ci_method = ci_method,
         p_adjust = p_adjust,
         wb_component = wb_component,
         keep_parameters = NULL,
         drop_parameters = NULL,
         keep_component_column = component != "conditional",
+        include_sigma = include_sigma,
+        summary = summary,
         ...
       )
     }
 
     # add dispersion parameter
-    if (inherits(model, "glmmTMB") && !is.null(params$Component) && !"dispersion" %in% params$Component) {
+    if (
+      # must be glmmTMB
+      inherits(model, "glmmTMB") &&
+      # don't print dispersion if already present
+      (is.null(component) || !"dispersion" %in% params$Component) &&
+      # don't print dispersion for zi-component
+      component %in% c("conditional", "all", "dispersion")
+    ) {
       dispersion_param <- insight::get_parameters(model, component = "dispersion")
       if (!is.null(dispersion_param)) {
+        # add component column
+        if (is.null(params$Component)) {
+          params$Component <- "conditional"
+        }
         params[nrow(params) + 1, ] <- NA
         params[nrow(params), "Parameter"] <- dispersion_param$Parameter[1]
-        params[nrow(params), "Coefficient"] <- dispersion_param$Estimate[1]
+        params[nrow(params), "Coefficient"] <- stats::sigma(model)
         params[nrow(params), "Component"] <- dispersion_param$Component[1]
+        params[nrow(params), c("CI_low", "CI_high")] <- stats::confint(model, parm = "sigma", method = "wald", level = ci)[1:2]
+        dispersion_param <- TRUE
       }
     }
 
@@ -109,16 +125,33 @@ model_parameters.glmmTMB <- function(model,
   }
 
   att <- attributes(params)
+  random_effects <- insight::find_random(model, flatten = TRUE)
 
-  if (effects %in% c("random", "all") && isTRUE(group_level)) {
-    params_random <- .extract_random_parameters(model, ci = ci, effects = effects, component = component)
+  # check if any random effects at all
+  if (!is.null(random_effects) && effects %in% c("random", "all")) {
+    # add random parameters or variances
+    if (isTRUE(group_level)) {
+      params_random <- .extract_random_parameters(model, ci = ci, effects = effects, component = component)
+      if (length(random_effects) > 1) {
+        warning(insight::format_message("Cannot extract confidence intervals for random variance parameters from models with more than one grouping factor."), call. = FALSE)
+      }
+    } else {
+      params_variance <- .extract_random_variances(model, ci = ci, effects = effects, component = component, ci_method = ci_method, verbose = verbose)
+      # remove redundant dispersion parameter
+      if (isTRUE(dispersion_param) && !is.null(params) && !is.null(params$Component)) {
+        disp <- which(params$Component == "dispersion")
+        resid <- which(params_variance$Group == "Residual")
+        # check if we have dispersion parameter, and either no sigma
+        # or sigma equals dispersion
+        if (length(disp) && length(resid) && all.equal(params_variance$Coefficient[resid],
+                                                       params$Coefficient[disp],
+                                                       tolerance = 1e-5)) {
+          params <- params[-disp, ]
+        }
+      }
+    }
   }
 
-  if (effects %in% c("random", "all") && isFALSE(group_level)) {
-    params_variance <- .extract_random_variances(model, ci = ci, effects = effects, component = component, ci_method = ci_method)
-  }
-
-
   # merge random and fixed effects, if necessary
   if (!is.null(params) && (!is.null(params_random) || !is.null(params_variance))) {
     params$Level <- NA
@@ -157,13 +190,14 @@ model_parameters.glmmTMB <- function(model,
   params <- .add_model_parameters_attributes(
     params,
     model,
-    ci = ifelse(effects == "random" && isFALSE(group_level), NA, ci),
+    ci = ci,
     exponentiate,
     ci_method = ci_method,
     p_adjust = p_adjust,
     verbose = verbose,
     group_level = group_level,
     summary = summary,
+    wb_component = wb_component,
     ...
   )
 
@@ -183,13 +217,11 @@ ci.glmmTMB <- function(x,
                        ci = .95,
                        dof = NULL,
                        method = "wald",
-                       robust = FALSE,
                        component = "all",
                        verbose = TRUE,
                        ...) {
-
   method <- tolower(method)
-  method <- match.arg(method, choices = c("wald", "normal", "ml1", "betwithin", "profile", "uniroot"))
+  method <- match.arg(method, choices = c("wald", "normal", "ml1", "betwithin", "profile", "uniroot", "robust"))
   component <- match.arg(component, choices = c("all", "conditional", "zi", "zero_inflated", "dispersion"))
 
   if (is.null(.check_component(x, component, verbose = verbose))) {
@@ -209,7 +241,7 @@ ci.glmmTMB <- function(x,
   } else {
 
     # all other
-    .ci_generic(model = x, ci = ci, dof = dof, method = method, robust = robust, component = component, ...)
+    .ci_generic(model = x, ci = ci, dof = dof, method = method, component = component, ...)
   }
 }
 
@@ -249,7 +281,7 @@ standard_error.glmmTMB <- function(model,
       return(NULL)
     }
 
-    cs <- .compact_list(stats::coef(summary(model)))
+    cs <- datawizard::compact_list(stats::coef(summary(model)))
     x <- lapply(names(cs), function(i) {
       .data_frame(
         Parameter = insight::find_parameters(model, effects = "fixed", component = i, flatten = TRUE),
@@ -379,6 +411,8 @@ simulate_parameters.glmmTMB <- function(model,
   attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
   attr(out, "iterations") <- iterations
   attr(out, "ci") <- ci
+  attr(out, "ci_method") <- ci_method
+  attr(out, "centrality") <- centrality
 
   out
 }
