@@ -32,17 +32,18 @@
 #' @param ... Arguments passed to or from other methods.
 #'
 #' @examples
+#'
 #' model <- cor.test(mtcars$mpg, mtcars$cyl, method = "pearson")
 #' model_parameters(model)
 #'
 #' model <- t.test(iris$Sepal.Width, iris$Sepal.Length)
-#' model_parameters(model)
+#' model_parameters(model, hedges_g = TRUE)
 #'
 #' model <- t.test(mtcars$mpg ~ mtcars$vs)
-#' model_parameters(model)
+#' model_parameters(model, hedges_g = TRUE)
 #'
 #' model <- t.test(iris$Sepal.Width, mu = 1)
-#' model_parameters(model)
+#' model_parameters(model, standardized_d = TRUE)
 #'
 #' data(airquality)
 #' airquality$Month <- factor(airquality$Month, labels = month.abb[5:9])
@@ -53,7 +54,12 @@
 #' patients <- c(86, 93, 136, 82)
 #' model <- pairwise.prop.test(smokers, patients)
 #' model_parameters(model)
+#'
+#' model <- stats::chisq.test(table(mtcars$am, mtcars$cyl))
+#' model_parameters(model, cramers_v = "adjusted")
+#'
 #' @return A data frame of indices related to the model's parameters.
+#'
 #' @export
 model_parameters.htest <- function(model,
                                    cramers_v = NULL,
@@ -164,7 +170,7 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
                                       alternative = NULL,
                                       verbose = TRUE,
                                       ...) {
-  m_info <- insight::model_info(model)
+  m_info <- insight::model_info(model, verbose = FALSE)
 
   if (m_info$is_correlation) {
 
@@ -239,9 +245,22 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
     # chi2- and mcnemar-test -----------
     out <- .extract_htest_chi2(model)
     if (grepl("^McNemar", model$method)) {
-      out <- .add_effectsize_mcnemar(model, out, cohens_g = cohens_g, ci = ci, verbose = verbose)
+      out <- .add_effectsize_mcnemar(model,
+        out,
+        cohens_g = cohens_g,
+        ci = ci,
+        verbose = verbose
+      )
     } else {
-      out <- .add_effectsize_chi2(model, out, cramers_v = cramers_v, phi = phi, ci = ci, alternative = alternative, verbose = verbose)
+      out <- .add_effectsize_chi2(
+        model,
+        out,
+        cramers_v = cramers_v,
+        phi = phi,
+        ci = ci,
+        alternative = alternative,
+        verbose = verbose
+      )
     }
   } else if (m_info$is_proptest) {
 
@@ -515,8 +534,8 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
 
 .extract_htest_chi2 <- function(model) {
   # survey-chisq-test
-  if (("observed" %in% names(model) && inherits(model$observed, "svytable")) ||
-    grepl("^svychisq", model$data.name)) {
+  if ((any("observed" %in% names(model)) && inherits(model$observed, "svytable")) ||
+    any(grepl("^svychisq", model$data.name))) {
     if (grepl("Pearson's X", model$method, fixed = TRUE)) {
       model$method <- gsub("(Pearson's X\\^2: )(.*)", "Pearson's Chi2 \\(\\2\\)", model$method)
     }
@@ -547,7 +566,8 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
         "CI_high" = model$conf.int[2],
         "p" = model$p.value,
         "Method" = model$method,
-        stringsAsFactors = FALSE
+        stringsAsFactors = FALSE,
+        check.names = FALSE
       )
     } else {
       data.frame(
@@ -618,6 +638,8 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
 # ==== effectsizes =====
 
 
+# effectsize Chi2 (Phi / Cramer's V) ----
+
 .add_effectsize_chi2 <- function(model,
                                  out,
                                  cramers_v = NULL,
@@ -674,6 +696,8 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
 
 
 
+# effectsize Chi2 (McNemar) ----
+
 .add_effectsize_mcnemar <- function(model,
                                     out,
                                     cohens_g = NULL,
@@ -703,6 +727,8 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
 
 
 
+# effectsize Cohen's d / Hedges g (t-test) ----
+
 .add_effectsize_ttest <- function(model,
                                   out,
                                   standardized_d = NULL,
@@ -766,6 +792,10 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
 }
 
 
+
+
+# effectsize r (rank biserial) ----
+
 .add_effectsize_rankbiserial <- function(model,
                                          out,
                                          rank_biserial = NULL,
@@ -778,7 +808,7 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
 
   if (requireNamespace("effectsize", quietly = TRUE)) {
     es <- effectsize::effectsize(model,
-      type = "r_rank_biserial",
+      type = "rank_biserial",
       ci = ci,
       verbose = verbose,
       ...
@@ -799,6 +829,10 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
   out
 }
 
+
+
+# effectsize rank Epsilon2 ----
+
 .add_effectsize_rankepsilon <- function(model,
                                         out,
                                         rank_epsilon_squared = NULL,
@@ -833,6 +867,11 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
   out
 }
 
+
+
+
+# effectsize Kendall's W ----
+
 .add_effectsize_kendalls_w <- function(model,
                                        out,
                                        kendalls_w = NULL,
@@ -866,6 +905,11 @@ model_parameters.pairwise.htest <- function(model, verbose = TRUE, ...) {
   out
 }
 
+
+
+
+# effectsize One-way Anova (Omega, Eta, ...) ----
+
 .add_effectsize_oneway <- function(model,
                                    out,
                                    omega_squared = NULL,
