@@ -127,7 +127,7 @@ model_parameters.rma <- function(model,
 
   # subgroup analyses?
   if (!is.null(subgroups)) {
-    meta_analysis_studies$Subgroup <- insight::get_data(model)[[group_variable]]
+    meta_analysis_studies$Subgroup <- insight::get_data(model, verbose = FALSE)[[group_variable]]
   }
 
   original_attributes <- attributes(meta_analysis_overall)
@@ -185,7 +185,7 @@ ci.rma <- function(x, ci = .95, ...) {
           CI_high = as.vector(model$ci.ub)
         )
       })
-      .remove_backticks_from_parameter_names(do.call(rbind, tmp))
+      insight::text_remove_backticks(do.call(rbind, tmp), verbose = FALSE)
     },
     error = function(e) {
       NULL
@@ -203,7 +203,7 @@ ci.rma <- function(x, ci = .95, ...) {
         CI_high = params$Estimate + as.vector(se$SE) * fac
       )
     })
-    out <- .remove_backticks_from_parameter_names(do.call(rbind, out))
+    out <- insight::text_remove_backticks(do.call(rbind, out), verbose = FALSE)
   }
   out
 }
