@@ -9,7 +9,6 @@ model_parameters.logitor <- function(model,
                                      iterations = 1000,
                                      standardize = NULL,
                                      exponentiate = TRUE,
-                                     robust = FALSE,
                                      p_adjust = NULL,
                                      verbose = TRUE,
                                      ...) {
@@ -20,7 +19,6 @@ model_parameters.logitor <- function(model,
     iterations = iterations,
     standardize = standardize,
     exponentiate = exponentiate,
-    robust = robust,
     p_adjust = p_adjust,
     ...
   )
@@ -44,7 +42,6 @@ model_parameters.poissonmfx <- function(model,
                                         component = c("all", "conditional", "marginal"),
                                         standardize = NULL,
                                         exponentiate = FALSE,
-                                        robust = FALSE,
                                         p_adjust = NULL,
                                         verbose = TRUE,
                                         ...) {
@@ -58,7 +55,6 @@ model_parameters.poissonmfx <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     component = component,
-    robust = robust,
     p_adjust = p_adjust,
     ...
   )
@@ -115,7 +111,6 @@ model_parameters.betamfx <- function(model,
                                      component = c("all", "conditional", "precision", "marginal"),
                                      standardize = NULL,
                                      exponentiate = FALSE,
-                                     robust = FALSE,
                                      p_adjust = NULL,
                                      verbose = TRUE,
                                      ...) {
@@ -129,7 +124,6 @@ model_parameters.betamfx <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     component = component,
-    robust = robust,
     p_adjust = p_adjust,
     ...
   )
@@ -146,8 +140,7 @@ model_parameters.betamfx <- function(model,
 
 #' @export
 ci.logitor <- function(x, ci = .95, method = NULL, ...) {
-  robust <- !is.null(method) && method == "robust"
-  ci_wald(model = x$fit, ci = ci, robust = robust, ...)
+  .ci_generic(model = x$fit, ci = ci, method = method, ...)
 }
 
 
@@ -159,7 +152,6 @@ ci.poissonirr <- ci.logitor
 ci.negbinirr <- ci.logitor
 
 
-#' @rdname ci.merMod
 #' @export
 ci.poissonmfx <- function(x,
                           ci = .95,
@@ -167,8 +159,7 @@ ci.poissonmfx <- function(x,
                           method = NULL,
                           ...) {
   component <- match.arg(component)
-  robust <- !is.null(method) && method == "robust"
-  ci_wald(model = x, ci = ci, component = component, robust = robust, ...)
+  .ci_generic(model = x, ci = ci, component = component, method = method, ...)
 }
 
 
@@ -190,20 +181,18 @@ ci.betaor <- function(x,
                       component = c("all", "conditional", "precision"),
                       ...) {
   component <- match.arg(component)
-  ci_wald(model = x$fit, ci = ci, dof = Inf, component = component)
+  .ci_generic(model = x$fit, ci = ci, dof = Inf, component = component)
 }
 
 
-#' @rdname ci.merMod
 #' @export
 ci.betamfx <- function(x,
                        ci = .95,
-                       component = c("all", "conditional", "precision", "marginal"),
                        method = NULL,
+                       component = c("all", "conditional", "precision", "marginal"),
                        ...) {
   component <- match.arg(component)
-  robust <- !is.null(method) && method == "robust"
-  ci_wald(model = x, ci = ci, component = component, robust = robust, ...)
+  .ci_generic(model = x, ci = ci, component = component, method = method, ...)
 }
 
 
@@ -218,7 +207,7 @@ standard_error.negbin <- standard_error.default
 
 #' @export
 standard_error.logitor <- function(model, ...) {
-  standard_error.lm(model$fit, ...)
+  standard_error.default(model$fit, ...)
 }
 
 
@@ -349,10 +338,13 @@ degrees_of_freedom.betamfx <- degrees_of_freedom.logitor
 
 #' p-values for Marginal Effects Models
 #'
-#' This function attempts to return, or compute, p-values of marginal effects models from package \pkg{mfx}.
+#' This function attempts to return, or compute, p-values of marginal effects
+#' models from package \pkg{mfx}.
 #'
 #' @param model A statistical model.
-#' @param component Should all parameters, parameters for the conditional model, precision-component or marginal effects be returned? \code{component} may be one of \code{"conditional"}, \code{"precision"}, \code{"marginal"} or \code{"all"} (default).
+#' @param component Should all parameters, parameters for the conditional model,
+#'   precision-component or marginal effects be returned? `component` may be one
+#'   of `"conditional"`, `"precision"`, `"marginal"` or `"all"` (default).
 #' @param ... Currently not used.
 #'
 #' @return A data frame with at least two columns: the parameter names and the
@@ -372,7 +364,9 @@ degrees_of_freedom.betamfx <- degrees_of_freedom.logitor
 #'   p_value(model, component = "marginal")
 #' }
 #' @export
-p_value.poissonmfx <- function(model, component = c("all", "conditional", "marginal"), ...) {
+p_value.poissonmfx <- function(model,
+                               component = c("all", "conditional", "marginal"),
+                               ...) {
   parms <- insight::get_parameters(model, component = "all")
   cs <- stats::coef(summary(model$fit))
   p <- c(as.vector(model$mfxest[, 4]), as.vector(cs[, 4]))
@@ -420,7 +414,9 @@ p_value.negbinmfx <- p_value.poissonmfx
 
 #' @rdname p_value.poissonmfx
 #' @export
-p_value.betaor <- function(model, component = c("all", "conditional", "precision"), ...) {
+p_value.betaor <- function(model,
+                           component = c("all", "conditional", "precision"),
+                           ...) {
   component <- match.arg(component)
   p_value.betareg(model$fit, component = component, ...)
 }
@@ -428,7 +424,9 @@ p_value.betaor <- function(model, component = c("all", "conditional", "precision
 
 #' @rdname p_value.poissonmfx
 #' @export
-p_value.betamfx <- function(model, component = c("all", "conditional", "precision", "marginal"), ...) {
+p_value.betamfx <- function(model,
+                            component = c("all", "conditional", "precision", "marginal"),
+                            ...) {
   parms <- insight::get_parameters(model, component = "all")
   cs <- do.call(rbind, stats::coef(summary(model$fit)))
   p <- c(as.vector(model$mfxest[, 4]), as.vector(cs[, 4]))
@@ -454,9 +452,17 @@ p_value.betamfx <- function(model, component = c("all", "conditional", "precisio
 
 
 #' @export
-simulate_model.betaor <- function(model, iterations = 1000, component = c("all", "conditional", "precision"), ...) {
+simulate_model.betaor <- function(model,
+                                  iterations = 1000,
+                                  component = c("all", "conditional", "precision"),
+                                  ...) {
   component <- match.arg(component)
-  simulate_model.betareg(model$fit, iterations = iterations, component = component, ...)
+
+  simulate_model.betareg(model$fit,
+    iterations = iterations,
+    component = component,
+    ...
+  )
 }
 
 
