@@ -9,6 +9,7 @@ model_parameters.mixor <- function(model,
                                    standardize = NULL,
                                    exponentiate = FALSE,
                                    verbose = TRUE,
+                                   include_sigma = FALSE,
                                    ...) {
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
 
@@ -29,7 +30,7 @@ model_parameters.mixor <- function(model,
     standardize = standardize,
     exponentiate = exponentiate,
     effects = effects,
-    robust = FALSE,
+    include_sigma = include_sigma,
     ...
   )
 
@@ -42,7 +43,7 @@ model_parameters.mixor <- function(model,
 #' @export
 ci.mixor <- function(x, ci = .95, effects = "all", ...) {
   effects <- match.arg(effects, choices = c("all", "fixed", "random"))
-  .ci_generic(model = x, ci = ci, dof = Inf, effects = effects, robust = FALSE, ...)
+  .ci_generic(model = x, ci = ci, dof = Inf, effects = effects, ...)
 }
 
 
