@@ -14,10 +14,10 @@
 #' @details Multinomial or cumulative link models, i.e. models where the
 #'   response value (dependent variable) is categorical and has more than two
 #'   levels, usually return coefficients for each response level. Hence, the
-#'   output from \code{model_parameters()} will split the coefficient tables
+#'   output from `model_parameters()` will split the coefficient tables
 #'   by the different levels of the model's response.
 #'
-#' @seealso \code{\link[insight:standardize_names]{standardize_names()}} to rename
+#' @seealso [insight::standardize_names()] to rename
 #'   columns into a consistent, standardized naming scheme.
 #'
 #' @examples
@@ -52,11 +52,8 @@ model_parameters.mlm <- function(model,
     merge_by = c("Parameter", "Response"),
     standardize = standardize,
     exponentiate = exponentiate,
-    robust = FALSE,
     p_adjust = p_adjust,
-    ...
-  )
-
+    ...)
   attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
   out
 }
@@ -73,7 +70,7 @@ standard_error.mlm <- function(model, ...) {
       Response = gsub("^Response (.*)", "\\1", x)
     )
   })
-  .remove_backticks_from_parameter_names(do.call(rbind, se))
+  insight::text_remove_backticks(do.call(rbind, se), verbose = FALSE)
 }
 
 
@@ -88,7 +85,7 @@ p_value.mlm <- function(model, ...) {
       Response = gsub("^Response (.*)", "\\1", x)
     )
   })
-  .remove_backticks_from_parameter_names(do.call(rbind, p))
+  insight::text_remove_backticks(do.call(rbind, p), verbose = FALSE)
 }
 
 
@@ -99,16 +96,16 @@ ci.mlm <- function(x, ci = .95, ...) {
       .ci <- stats::confint(x, level = i, ...)
       rn <- rownames(.ci)
       .data_frame(
-        Parameter = gsub("^(.*):(.*)", "\\2", rn),
+        Parameter = gsub("([^\\:]+)(\\:)(.*)", "\\3", rn),
         CI = i,
         CI_low = .ci[, 1],
         CI_high = .ci[, 2],
-        Response = gsub("^(.*):(.*)", "\\1", rn)
+        Response = gsub("([^\\:]+)(\\:)(.*)", "\\1", rn)
       )
     })
-    out <- .remove_backticks_from_parameter_names(do.call(rbind, out))
+    out <- insight::text_remove_backticks(do.call(rbind, out), verbose = FALSE)
   } else {
-    out <- .data_frame(ci_wald(x, ci = ci, ...), Response = insight::get_parameters(x)$Response)
+    out <- .data_frame(.ci_generic(x, ci = ci, ...), Response = insight::get_parameters(x)$Response)
   }
   out
 }
@@ -159,6 +156,8 @@ simulate_parameters.mlm <- function(model,
   attr(out, "object_class") <- class(model)
   attr(out, "iterations") <- iterations
   attr(out, "ci") <- ci
+  attr(out, "ci_method") <- ci_method
+  attr(out, "centrality") <- centrality
 
   out
 }
