@@ -22,7 +22,6 @@ model_parameters.mvord <- function(model,
     merge_by = c("Parameter", "Component", "Response"),
     standardize = standardize,
     exponentiate = exponentiate,
-    robust = FALSE,
     p_adjust = p_adjust,
     ...
   )
@@ -37,9 +36,11 @@ standard_error.mvord <- function(model, component = c("all", "conditional", "thr
   params <- insight::get_parameters(model, component = "all")
   junk <- utils::capture.output(s <- summary(model))
 
-  params$SE <- c(unname(s$thresholds[, "Std. Error"]),
-                 unname(s$coefficients[, "Std. Error"]),
-                 unname(s$error.structure[, "Std. Error"]))
+  params$SE <- c(
+    unname(s$thresholds[, "Std. Error"]),
+    unname(s$coefficients[, "Std. Error"]),
+    unname(s$error.structure[, "Std. Error"])
+  )
 
   params <- params[c("Parameter", "SE", "Component", "Response")]
 
@@ -51,7 +52,7 @@ standard_error.mvord <- function(model, component = c("all", "conditional", "thr
     params <- params[params$Component == component, , drop = FALSE]
   }
 
-  .remove_backticks_from_parameter_names(params)
+  insight::text_remove_backticks(params, verbose = FALSE)
 }
 
 
@@ -61,9 +62,11 @@ p_value.mvord <- function(model, component = c("all", "conditional", "thresholds
   params <- insight::get_parameters(model, component = "all")
   junk <- utils::capture.output(s <- summary(model))
 
-  params$p <- c(unname(s$thresholds[, "Pr(>|z|)"]),
-                unname(s$coefficients[, "Pr(>|z|)"]),
-                unname(s$error.structure[, "Pr(>|z|)"]))
+  params$p <- c(
+    unname(s$thresholds[, "Pr(>|z|)"]),
+    unname(s$coefficients[, "Pr(>|z|)"]),
+    unname(s$error.structure[, "Pr(>|z|)"])
+  )
 
   params <- params[c("Parameter", "p", "Component", "Response")]
 
@@ -75,7 +78,7 @@ p_value.mvord <- function(model, component = c("all", "conditional", "thresholds
     params <- params[params$Component == component, , drop = FALSE]
   }
 
-  .remove_backticks_from_parameter_names(params)
+  insight::text_remove_backticks(params, verbose = FALSE)
 }
 
 
