@@ -17,12 +17,10 @@ model_parameters.zerocount <- model_parameters.zcpglm
 
 # ci -----------------
 
-#' @rdname ci.merMod
 #' @export
 ci.zeroinfl <- ci.glmmTMB
 
 
-#' @rdname ci.merMod
 #' @export
 ci.hurdle <- ci.glmmTMB
 
@@ -49,11 +47,11 @@ standard_error.zeroinfl <- function(model,
   }
 
   robust <- !is.null(method) && method == "robust"
-  if (isTRUE(robust)) {
-    return(standard_error_robust(model, ...))
+  if (.check_vcov_args(robust, ...)) {
+    return(standard_error.default(model, component = component, ...))
   }
 
-  cs <- .compact_list(stats::coef(summary(model)))
+  cs <- datawizard::compact_list(stats::coef(summary(model)))
   x <- lapply(names(cs), function(i) {
     comp <- ifelse(i == "count", "conditional", "zi")
 
@@ -102,11 +100,11 @@ p_value.zeroinfl <- function(model, component = c("all", "conditional", "zi", "z
   }
 
   robust <- !is.null(method) && method == "robust"
-  if (isTRUE(robust)) {
-    return(p_value_robust(model, ...))
+  if (.check_vcov_args(robust, ...)) {
+    return(p_value.default(model, component = component, ...))
   }
 
-  cs <- .compact_list(stats::coef(summary(model)))
+  cs <- datawizard::compact_list(stats::coef(summary(model)))
   x <- lapply(names(cs), function(i) {
     comp <- ifelse(i == "count", "conditional", "zi")
     stats <- cs[[i]]
@@ -195,6 +193,8 @@ simulate_parameters.zeroinfl <- function(model,
   attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
   attr(out, "iterations") <- iterations
   attr(out, "ci") <- ci
+  attr(out, "ci_method") <- ci_method
+  attr(out, "centrality") <- centrality
 
   out
 }
