@@ -3,29 +3,27 @@
 #' @export
 model_parameters.svyglm <- function(model,
                                     ci = .95,
-                                    df_method = "wald",
+                                    ci_method = "wald",
                                     bootstrap = FALSE,
                                     iterations = 1000,
                                     standardize = NULL,
                                     exponentiate = FALSE,
-                                    robust = FALSE,
                                     p_adjust = NULL,
                                     verbose = TRUE,
                                     ...) {
-  if (insight::n_obs(model) > 1e4 && df_method == "likelihood") {
+  if (insight::n_obs(model) > 1e4 && ci_method == "likelihood") {
     message(insight::format_message("Likelihood confidence intervals may take longer time to compute. Use 'df_method=\"wald\"' for faster computation of CIs."))
   }
 
   out <- .model_parameters_generic(
     model = model,
     ci = ci,
-    df_method = df_method,
+    ci_method = ci_method,
     bootstrap = bootstrap,
     iterations = iterations,
     merge_by = "Parameter",
     standardize = standardize,
     exponentiate = exponentiate,
-    robust = robust,
     p_adjust = p_adjust,
     ...
   )
@@ -83,15 +81,14 @@ standard_error.svyolr <- standard_error.svyglm
 
 # confidence intervals -----------------------------------
 
-#' @rdname ci.merMod
 #' @export
-ci.svyglm <- function(x, ci = .95, method = c("wald", "likelihood"), ...) {
-  method <- match.arg(method)
+ci.svyglm <- function(x, ci = .95, method = "wald", ...) {
+  method <- match.arg(method, choices = c("wald", "residual", "normal", "likelihood"))
   if (method == "likelihood") {
     out <- lapply(ci, function(i) .ci_likelihood(model = x, ci = i))
     out <- do.call(rbind, out)
   } else {
-    out <- ci_wald(model = x, ci = ci)
+    out <- .ci_generic(model = x, ci = ci, method = method, ...)
   }
 
   row.names(out) <- NULL
@@ -101,19 +98,12 @@ ci.svyglm <- function(x, ci = .95, method = c("wald", "likelihood"), ...) {
 #' @export
 ci.svyolr <- ci.svyglm
 
-#' @export
-ci.svyglm.nb <- ci.tobit
-
-#' @export
-ci.svyglm.glimML <- ci.tobit
-
-#' @export
-ci.svyglm.zip <- ci.tobit
-
 
 
 # p values -----------------------------------------------
 
+## TODO how to calculate p when ci-method is "likelihood"?
+
 #' @export
 p_value.svyglm <- function(model, verbose = TRUE, ...) {
   statistic <- insight::get_statistic(model)
@@ -175,7 +165,7 @@ p_value.svyglm.zip <- p_value.svyglm.nb
   )
 
   if (is.null(glm_ci)) {
-    glm_ci <- ci_wald(model, ci = ci)
+    glm_ci <- .ci_generic(model, ci = ci)
   }
 
   glm_ci
