@@ -1,13 +1,13 @@
 # classes: .truncreg
 
 
-#' @export
-ci.truncreg <- ci.tobit
-
-
 #' @export
 standard_error.truncreg <- standard_error.default
 
 
 #' @export
 p_value.truncreg <- p_value.default
+
+
+#' @export
+degrees_of_freedom.truncreg <- degrees_of_freedom.mhurdle
