@@ -7,16 +7,19 @@ model_parameters.varest <- function(model,
                                     iterations = 1000,
                                     standardize = NULL,
                                     exponentiate = FALSE,
-                                    robust = FALSE,
                                     p_adjust = NULL,
                                     verbose = TRUE,
                                     ...) {
   params <- lapply(names(model$varresult), function(i) {
     out <- model_parameters(
-      model = model$varresult[[i]], ci = ci,
-      bootstrap = bootstrap, iterations = iterations,
-      standardize = standardize, exponentiate = exponentiate,
-      robust = robust, p_adjust = p_adjust, verbose = verbose,
+      model = model$varresult[[i]],
+      ci = ci,
+      bootstrap = bootstrap,
+      iterations = iterations,
+      standardize = standardize,
+      exponentiate = exponentiate,
+      p_adjust = p_adjust,
+      verbose = verbose,
       ...
     )
     out$Group <- paste0("Equation ", i)
@@ -108,6 +111,8 @@ simulate_parameters.varest <- function(model,
   attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
   attr(out, "iterations") <- iterations
   attr(out, "ci") <- ci
+  attr(out, "ci_method") <- ci_method
+  attr(out, "centrality") <- centrality
 
   out
 }
