@@ -5,25 +5,25 @@
 #'
 #' @param model A statistical model.
 #' @param dof Degrees of Freedom.
-#' @inheritParams ci.merMod
+#' @inheritParams ci.default
 #'
 #' @details Inferential statistics (like p-values, confidence intervals and
 #' standard errors) may be biased in mixed models when the number of clusters
 #' is small (even if the sample size of level-1 units is high). In such cases
 #' it is recommended to approximate a more accurate number of degrees of freedom
 #' for such inferential statistics. Unlike simpler approximation heuristics
-#' like the "m-l-1" rule (\code{dof_ml1}), the Kenward-Roger approximation is
+#' like the "m-l-1" rule (`dof_ml1`), the Kenward-Roger approximation is
 #' also applicable in more complex multilevel designs, e.g. with cross-classified
 #' clusters. However, the "m-l-1" heuristic also applies to generalized
 #' mixed models, while approaches like Kenward-Roger or Satterthwaite are limited
 #' to linear mixed models only.
 #'
-#' @seealso \code{dof_kenward()} and \code{se_kenward()} are small helper-functions
+#' @seealso `dof_kenward()` and `se_kenward()` are small helper-functions
 #' to calculate approximated degrees of freedom and standard errors for model
 #' parameters, based on the Kenward-Roger (1997) approach.
 #' \cr \cr
-#' \code{\link[=dof_satterthwaite]{dof_satterthwaite()}} and
-#' \code{\link[=dof_ml1]{dof_ml1()}} approximate degrees
+#' [`dof_satterthwaite()`][dof_satterthwaite] and
+#' [`dof_ml1()`][dof_ml1] approximate degrees
 #' of freedom based on Satterthwaite's method or the "m-l-1" rule.
 #'
 #' @examples
@@ -53,19 +53,53 @@ p_value_kenward.lmerMod <- function(model, dof = NULL) {
 
 
 
-
 # helper ------------------------------
 
-.p_value_dof <- function(model, dof, method, statistic = NULL, se = NULL) {
-  params <- insight::get_parameters(model)
-  if (is.null(statistic)) {
-    statistic <- insight::get_statistic(model)$Statistic
+.p_value_dof <- function(model,
+                         dof,
+                         method = NULL,
+                         statistic = NULL,
+                         se = NULL,
+                         component = c("all", "conditional", "zi", "zero_inflated", "dispersion", "precision", "scale", "smooth_terms", "full", "marginal"),
+                         effects = c("fixed", "random", "all"),
+                         verbose = TRUE,
+                         vcov = NULL,
+                         vcov_args = NULL,
+                         ...) {
+
+  component <- match.arg(component)
+  effects <- match.arg(effects)
+
+  if (is.null(.check_component(model, component, verbose = verbose))) {
+    return(NULL)
   }
 
-  if (method == "kenward") {
+  params <- insight::get_parameters(model, component = component)
+
+  # check if all estimates are non-NA
+  params <- .check_rank_deficiency(params, verbose = FALSE)
+
+  if (is.null(statistic)) {
+    statistic <- insight::get_statistic(model, component = component)
+    params <- merge(params, statistic, sort = FALSE)
+    statistic <- params$Statistic
+  }
+
+  # different SE for kenward and robust
+  if (identical(method, "kenward") || identical(method, "kr")) {
     if (is.null(se)) {
       se <- se_kenward(model)$SE
     }
+  } else if (!is.null(vcov) || isTRUE(list(...)[["robust"]])) {
+    se <- standard_error(model,
+                         vcov = vcov,
+                         vcov_args = vcov_args,
+                         component = component,
+                         ...)$SE
+  }
+
+  # overwrite statistic, based on robust or kenward standard errors
+  if (identical(method, "kenward") || identical(method, "kr") || !is.null(vcov)) {
     estimate <- if ("Coefficient" %in% colnames(params)) {
       params$Coefficient
     } else {
@@ -75,10 +109,16 @@ p_value_kenward.lmerMod <- function(model, dof = NULL) {
   }
 
   p <- 2 * stats::pt(abs(statistic), df = dof, lower.tail = FALSE)
-  .data_frame(
+  out <- .data_frame(
     Parameter = params$Parameter,
     p = unname(p)
   )
+
+  if ("Component" %in% names(params)) out$Component <- params$Component
+  if ("Effects" %in% names(params) && effects != "fixed") out$Effects <- params$Effects
+  if ("Response" %in% names(params)) out$Response <- params$Response
+
+  out
 }
 
 
@@ -98,15 +138,11 @@ p_value_kenward.lmerMod <- function(model, dof = NULL) {
 }
 
 
-
-
-
 # helper -------------------------
 
 .check_REML_fit <- function(model) {
-  if (!requireNamespace("lme4", quietly = TRUE)) {
-    stop("Package 'lme4' required for this function to work. Please install it.")
-  }
+  insight::check_if_installed("lme4")
+
   if (!(lme4::getME(model, "is_REML"))) {
     warning(insight::format_message("Model was not fitted by REML. Re-fitting model now, but p-values, df, etc. still might be unreliable."), call. = FALSE)
   }
