@@ -1,4 +1,3 @@
-#' @importFrom insight clean_names
 #' @keywords internal
 .clean_parameter_names <- function(x, full = FALSE) {
   # return if x is empty
@@ -57,14 +56,6 @@
   x
 }
 
-#' @keywords internal
-.remove_backticks_from_parameter_names <- function(x) {
-  if (is.data.frame(x) && "Parameter" %in% colnames(x)) {
-    x$Parameter <- gsub("`", "", x$Parameter, fixed = TRUE)
-  }
-  x
-}
-
 #' @keywords internal
 .intercepts <- function() {
   c(
