@@ -7,10 +7,10 @@
                                              iterations = 1000,
                                              ci_method = NULL,
                                              p_adjust = NULL,
-                                             robust = FALSE,
                                              summary = FALSE,
                                              verbose = TRUE,
                                              group_level = FALSE,
+                                             wb_component = FALSE,
                                              ...) {
   # capture additional arguments
   dot.arguments <- lapply(match.call(expand.dots = FALSE)$`...`, function(x) x)
@@ -36,10 +36,12 @@
 
 
   # add regular attributes
-
-  if (is.null(attr(params, "pretty_names", exact = TRUE))) {
-    attr(params, "pretty_names") <- suppressWarnings(format_parameters(model))
+  if (isFALSE(dot.arguments$pretty_names)) {
+    attr(params, "pretty_names") <- params$Parameter
+  } else if (is.null(attr(params, "pretty_names", exact = TRUE))) {
+    attr(params, "pretty_names") <- suppressWarnings(format_parameters(model, model_info = info))
   }
+
   attr(params, "ci") <- ci
   attr(params, "ci_method") <- ci_method
   attr(params, "df_method") <- ci_method
@@ -54,31 +56,39 @@
   attr(params, "bootstrap") <- bootstrap
   attr(params, "iterations") <- iterations
   attr(params, "p_adjust") <- p_adjust
-  attr(params, "robust_vcov") <- isTRUE(robust)
+  attr(params, "robust_vcov") <- isTRUE(list(...)$robust) || "vcov" %in% names(list(...))
   attr(params, "ignore_group") <- isFALSE(group_level)
   attr(params, "ran_pars") <- isFALSE(group_level)
   attr(params, "show_summary") <- isTRUE(summary)
 
+  # save if model is multivariate response model
+  if (isTRUE(info$is_multivariate)) {
+    attr(params, "multivariate_response") <- TRUE
+  }
+
+  # if we have a complex random-within-between model, don't show first title element
+  if (isTRUE(wb_component) && !is.null(params$Component) && any(c("within", "between") %in% params$Component)) {
+    attr(params, "no_caption") <- TRUE
+  }
+
+
+  # for summaries, add R2
   if (isTRUE(summary)) {
     if (requireNamespace("performance", quietly = TRUE)) {
-      rsq <- tryCatch(
-        {
-          suppressWarnings(performance::r2(model))
-        },
-        error = function(e) {
-          NULL
-        }
-      )
+      rsq <- tryCatch(suppressWarnings(performance::r2(model)), error = function(e) NULL)
       attr(params, "r2") <- rsq
     }
   }
 
-  # here we add exception for objects that should not have a
-  # table headline
-  if (inherits(model, c("emmGrid", "emm_list", "lm", "glm", "coxph"))) {
+
+  # Models for which titles should be removed -
+  # here we add exceptions for objects that should
+  # not have a table headline
+  if (inherits(model, c("emmGrid", "emm_list", "lm", "glm", "coxph", "bfsl"))) {
     attr(params, "title") <- ""
   }
 
+
   # weighted nobs
   weighted_nobs <- tryCatch(
     {
@@ -91,6 +101,7 @@
   )
   attr(params, "weighted_nobs") <- weighted_nobs
 
+
   # model formula
   model_formula <- tryCatch(
     {
@@ -102,17 +113,28 @@
   )
   attr(params, "model_formula") <- model_formula
 
-  # column name for coefficients
-  coef_col <- .find_coefficient_type(info, exponentiate)
-  attr(params, "coefficient_name") <- coef_col
-  attr(params, "zi_coefficient_name") <- ifelse(isTRUE(exponentiate), "Odds Ratio", "Log-Odds")
 
-  # special handling for meta analysis. we need additional information
-  # about study weights
+  # column name for coefficients - for emm_list, we can have
+  # multiple different names for the parameter column. for other
+  # models, check whether we have coefficient, odds ratios, IRR etc.
+  if (inherits(model, "emm_list")) {
+    coef_col1 <- .find_coefficient_type(info, exponentiate, model[[1]])
+    coef_col2 <- .find_coefficient_type(info, exponentiate, model[[2]])
+    attr(params, "coefficient_name") <- coef_col1
+    attr(params, "coefficient_name2") <- coef_col2
+  } else {
+    coef_col <- .find_coefficient_type(info, exponentiate, model)
+    attr(params, "coefficient_name") <- coef_col
+    attr(params, "zi_coefficient_name") <- ifelse(isTRUE(exponentiate), "Odds Ratio", "Log-Odds")
+  }
+
+
+  # special handling for meta analysis. we need additional
+  # information about study weights
   if (inherits(model, c("rma", "rma.uni"))) {
     rma_data <- tryCatch(
       {
-        insight::get_data(model)
+        insight::get_data(model, verbose = FALSE)
       },
       error = function(e) {
         NULL
@@ -122,12 +144,13 @@
     attr(params, "study_weights") <- 1 / model$vi
   }
 
+
   # special handling for meta analysis again, but these objects save the
   # inverse weighting information in a different column.
   if (inherits(model, c("meta_random", "meta_fixed", "meta_bma"))) {
     rma_data <- tryCatch(
       {
-        insight::get_data(model)
+        insight::get_data(model, verbose = FALSE)
       },
       error = function(e) {
         NULL
@@ -137,10 +160,12 @@
     attr(params, "study_weights") <- 1 / params$SE^2
   }
 
+  # should coefficients be grouped?
   if ("groups" %in% names(dot.arguments)) {
     attr(params, "coef_groups") <- eval(dot.arguments[["groups"]])
   }
 
+  # now comes all the digits stuff...
   if ("digits" %in% names(dot.arguments)) {
     attr(params, "digits") <- eval(dot.arguments[["digits"]])
   } else {
@@ -169,6 +194,7 @@
     attr(params, "s_value") <- eval(dot.arguments[["s_value"]])
   }
 
+
   # add CI, and reorder
   if (!"CI" %in% colnames(params) && length(ci) == 1) {
     params$CI <- ci
@@ -189,10 +215,23 @@
 
 
 
-.find_coefficient_type <- function(info, exponentiate) {
+.find_coefficient_type <- function(info, exponentiate, model = NULL) {
   # column name for coefficients
   coef_col <- "Coefficient"
-  if (!is.null(info)) {
+  if (!is.null(model) && inherits(model, "emmGrid")) {
+    s <- summary(model)
+    name <- attributes(s)$estName
+    if (!is.null(name)) {
+      coef_col <- switch(name,
+        "prob"       = "Probability",
+        "odds.ratio" = "Odds Ratio",
+        "emmean"     = "Marginal Means",
+        "rate"       = "Estimated Counts",
+        "ratio"      = "Ratio",
+        "Coefficient"
+      )
+    }
+  } else if (!is.null(info)) {
     if (!info$family == "unknown") {
       if (isTRUE(exponentiate)) {
         if ((info$is_binomial && info$is_logit) || info$is_ordinal || info$is_multinomial || info$is_categorical) {
@@ -211,19 +250,20 @@
       }
     }
   }
+
   coef_col
 }
 
 
 .all_coefficient_types <- function() {
-  c("Odds Ratio", "Risk Ratio", "IRR", "Log-Odds", "Log-Mean")
+  c("Odds Ratio", "Risk Ratio", "IRR", "Log-Odds", "Log-Mean", "Probability", "Marginal Means", "Estimated Counts", "Ratio")
 }
 
 
 
 #' @keywords internal
 .exponentiate_parameters <- function(params, model = NULL, exponentiate = TRUE) {
-  if (!is.null(model) && insight::model_info(model)$is_linear && identical(exponentiate, "nongaussian")) {
+  if (!is.null(model) && insight::model_info(model, verbose = FALSE)$is_linear && identical(exponentiate, "nongaussian")) {
     return(params)
   }
   columns <- grepl(pattern = "^(Coefficient|Mean|Median|MAP|Std_Coefficient|CI_|Std_CI)", colnames(params))
