@@ -1,12 +1,14 @@
-if (require("testthat") &&
-  require("parameters") &&
-  require("gee")) {
+if (requiet("testthat") &&
+  requiet("parameters") &&
+  requiet("gee")) {
   data(warpbreaks)
-  m1 <- gee(breaks ~ tension, id = wool, data = warpbreaks)
+  void <- capture.output(
+    m1 <- suppressMessages(gee(breaks ~ tension, id = wool, data = warpbreaks))
+  )
 
   test_that("ci", {
     expect_equal(
-      ci(m1)$CI_low,
+      suppressMessages(ci(m1))$CI_low,
       c(30.90044, -17.76184, -22.48406),
       tolerance = 1e-3
     )
@@ -28,9 +30,10 @@ if (require("testthat") &&
     )
   })
 
+  mp <- suppressWarnings(model_parameters(m1))
   test_that("model_parameters", {
     expect_equal(
-      model_parameters(m1)$Coefficient,
+      mp$Coefficient,
       c(36.38889, -10, -14.72222),
       tolerance = 1e-3
     )
