@@ -148,7 +148,7 @@ if (.runThisTest &&
       model_parameters(m1, effects = "all")$Coefficient,
       c(
         1.2628, -1.14165, 0.73354, -0.38939, 2.05407, -1.00823, 0.9312,
-        1, 1.17399, 1
+        1, 1.17399
       ),
       tolerance = 1e-3
     )
@@ -159,11 +159,9 @@ if (.runThisTest &&
     )
     expect_equal(
       model_parameters(m3, effects = "fixed")$Coefficient,
-      c(
-        -0.6104, -0.9637, 0.1707, -0.3871, 0.4879, 0.5895, -0.1133,
-        1.4294, 0.91, 1.1614, -0.9393, 1.0424, -0.5623, -0.893, -2.5398,
-        -2.563, 0.4132
-      ),
+      c(-0.61038, -0.9637, 0.17068, -0.38706, 0.48795, 0.58949, -0.11327,
+        1.42935, 0.91004, 1.16141, -0.93932, 1.04243, -0.56231, -0.893,
+        -2.53981, -2.56303, 1.51165),
       tolerance = 1e-2
     )
     expect_equal(
@@ -171,7 +169,7 @@ if (.runThisTest &&
       c(
         "conditional", "conditional", "conditional", "zero_inflated",
         "zero_inflated", "zero_inflated", "conditional", "conditional",
-        "zero_inflated", "zero_inflated"
+        "zero_inflated"
       )
     )
     expect_null(model_parameters(m2, effects = "fixed")$Component)
@@ -235,29 +233,29 @@ if (.runThisTest &&
 
   test_that("model_parameters.mixed-ran_pars", {
     params <- model_parameters(m1, effects = "random")
-    expect_equal(c(nrow(params), ncol(params)), c(4, 9))
+    expect_equal(c(nrow(params), ncol(params)), c(3, 9))
     expect_equal(
       colnames(params),
       c("Parameter", "Coefficient", "SE", "CI", "CI_low", "CI_high", "Effects", "Group", "Component")
     )
     expect_equal(
       params$Parameter,
-      c("SD (Intercept)", "SD (Observations)", "SD (Intercept)", "SD (Observations)")
+      c("SD (Intercept)", "SD (Observations)", "SD (Intercept)")
     )
     expect_equal(
       params$Component,
-      c("conditional", "conditional", "zero_inflated", "zero_inflated")
+      c("conditional", "conditional", "zero_inflated")
     )
     expect_equal(
       params$Coefficient,
-      c(0.9312, 1, 1.17399, 1),
+      c(0.9312, 1, 1.17399),
       tolerance = 1e-2
     )
   })
 
   test_that("model_parameters.mixed-all_pars", {
     params <- model_parameters(m1, effects = "all")
-    expect_equal(c(nrow(params), ncol(params)), c(10, 12))
+    expect_equal(c(nrow(params), ncol(params)), c(9, 12))
     expect_equal(
       colnames(params),
       c(
@@ -269,8 +267,7 @@ if (.runThisTest &&
       params$Parameter,
       c(
         "(Intercept)", "child", "camper1", "(Intercept)", "child",
-        "camper1", "SD (Intercept)", "SD (Observations)", "SD (Intercept)",
-        "SD (Observations)"
+        "camper1", "SD (Intercept)", "SD (Observations)", "SD (Intercept)"
       )
     )
     expect_equal(
@@ -278,12 +275,12 @@ if (.runThisTest &&
       c(
         "conditional", "conditional", "conditional", "zero_inflated",
         "zero_inflated", "zero_inflated", "conditional", "conditional",
-        "zero_inflated", "zero_inflated"
+        "zero_inflated"
       )
     )
     expect_equal(
       params$Coefficient,
-      c(1.2628, -1.14165, 0.73354, -0.38939, 2.05407, -1.00823, 0.9312, 1, 1.17399, 1),
+      c(1.2628, -1.14165, 0.73354, -0.38939, 2.05407, -1.00823, 0.9312, 1, 1.17399),
       tolerance = 1e-2
     )
   })
@@ -327,6 +324,24 @@ if (.runThisTest &&
   })
 
 
+  data(mtcars)
+  mdisp <- glmmTMB(hp ~ 0 + wt/mpg, mtcars)
+  test_that("model_parameters, dispersion", {
+    mp <- model_parameters(mdisp)
+    expect_equal(mp$Coefficient, c(59.50992, -0.80396, 48.97731), tolerance = 1e-2)
+    expect_equal(mp$Parameter, c("wt", "wt:mpg", "(Intercept)"))
+    expect_equal(mp$Component, c("conditional", "conditional", "dispersion"))
+  })
+
+  mdisp <- glmmTMB(hp ~ 0 + wt/mpg + (1 | gear), mtcars)
+  test_that("model_parameters, dispersion", {
+    mp <- model_parameters(mdisp)
+    expect_equal(mp$Coefficient, c(58.25869, -0.87868, 47.01676, 36.99492), tolerance = 1e-2)
+    expect_equal(mp$Parameter, c("wt", "wt:mpg", "SD (Intercept)", "SD (Observations)"))
+    expect_equal(mp$Component, c("conditional", "conditional", "conditional", "conditional"))
+  })
+
+
   m4 <- suppressWarnings(glmmTMB(
     count ~ child + camper + (1 + xb | persons),
     ziformula = ~ child + camper + (1 + zg | persons),
@@ -336,7 +351,7 @@ if (.runThisTest &&
 
   test_that("model_parameters.mixed-ran_pars", {
     params <- model_parameters(m4, effects = "random")
-    expect_equal(c(nrow(params), ncol(params)), c(8, 9))
+    expect_equal(c(nrow(params), ncol(params)), c(7, 9))
     expect_equal(
       colnames(params),
       c("Parameter", "Coefficient", "SE", "CI", "CI_low", "CI_high", "Effects", "Group", "Component")
@@ -345,28 +360,27 @@ if (.runThisTest &&
       params$Parameter,
       c(
         "SD (Intercept)", "SD (xb)", "Cor (Intercept~xb: persons)", "SD (Observations)",
-        "SD (Intercept)", "SD (zg)", "Cor (Intercept~zg: persons)", "SD (Observations)"
+        "SD (Intercept)", "SD (zg)", "Cor (Intercept~zg: persons)"
       )
     )
     expect_equal(
       params$Component,
       c(
         "conditional", "conditional", "conditional", "conditional",
-        "zero_inflated", "zero_inflated", "zero_inflated", "zero_inflated"
+        "zero_inflated", "zero_inflated", "zero_inflated"
       )
     )
     expect_equal(
       params$Coefficient,
-      c(3.40563, 1.21316, -1, 1, 2.73583, 1.56833, 1, 1),
+      c(3.40563, 1.21316, -1, 1, 2.73583, 1.56833, 1),
       tolerance = 1e-2
     )
   })
 
 
-    # proper printing ---------------------
+  # proper printing ---------------------
 
   if (win_os) {
-
     test_that("print-model_parameters glmmTMB", {
       mp <- model_parameters(m4, effects = "fixed", component = "conditional")
       out <- utils::capture.output(print(mp))
@@ -389,12 +403,12 @@ if (.runThisTest &&
         c(
           "# Random Effects",
           "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |        3.41",
-          "SD (xb: persons)            |        1.21",
-          "Cor (Intercept~xb: persons) |       -1.00",
-          "SD (Residual)               |        1.00"
+          "Parameter                   | Coefficient |        95% CI",
+          "---------------------------------------------------------",
+          "SD (Intercept: persons)     |        3.41 | [ 1.67, 6.93]",
+          "SD (xb: persons)            |        1.21 | [ 0.60, 2.44]",
+          "Cor (Intercept~xb: persons) |       -1.00 | [-1.00, 1.00]",
+          "SD (Residual)               |        1.00 |              "
         )
       )
 
@@ -419,12 +433,11 @@ if (.runThisTest &&
         c(
           "# Random Effects (Zero-Inflated Model)",
           "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |        2.74",
-          "SD (zg: persons)            |        1.57",
-          "Cor (Intercept~zg: persons) |        1.00",
-          "SD (Residual)               |        1.00"
+          "Parameter                   | Coefficient |        95% CI",
+          "---------------------------------------------------------",
+          "SD (Intercept: persons)     |        2.74 | [ 1.16, 6.43]",
+          "SD (zg: persons)            |        1.57 | [ 0.64, 3.82]",
+          "Cor (Intercept~zg: persons) |        1.00 | [-1.00, 1.00]"
         )
       )
 
@@ -442,12 +455,12 @@ if (.runThisTest &&
           "",
           "# Random Effects",
           "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |        3.41",
-          "SD (xb: persons)            |        1.21",
-          "Cor (Intercept~xb: persons) |       -1.00",
-          "SD (Residual)               |        1.00"
+          "Parameter                   | Coefficient |        95% CI",
+          "---------------------------------------------------------",
+          "SD (Intercept: persons)     |        3.41 | [ 1.67, 6.93]",
+          "SD (xb: persons)            |        1.21 | [ 0.60, 2.44]",
+          "Cor (Intercept~xb: persons) |       -1.00 | [-1.00, 1.00]",
+          "SD (Residual)               |        1.00 |              "
         )
       )
 
@@ -465,12 +478,11 @@ if (.runThisTest &&
           "",
           "# Random Effects (Zero-Inflated Model)",
           "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |        2.74",
-          "SD (zg: persons)            |        1.57",
-          "Cor (Intercept~zg: persons) |        1.00",
-          "SD (Residual)               |        1.00"
+          "Parameter                   | Coefficient |        95% CI",
+          "---------------------------------------------------------",
+          "SD (Intercept: persons)     |        2.74 | [ 1.16, 6.43]",
+          "SD (zg: persons)            |        1.57 | [ 0.64, 3.82]",
+          "Cor (Intercept~zg: persons) |        1.00 | [-1.00, 1.00]"
         )
       )
 
@@ -495,21 +507,17 @@ if (.runThisTest &&
           "",
           "# Random Effects Variances",
           "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |        3.41",
-          "SD (xb: persons)            |        1.21",
-          "Cor (Intercept~xb: persons) |       -1.00",
-          "SD (Residual)               |        1.00",
-          "",
-          "# Random Effects (Zero-Inflated Model)",
-          "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |        2.74",
-          "SD (zg: persons)            |        1.57",
-          "Cor (Intercept~zg: persons) |        1.00",
-          "SD (Residual)               |        1.00"
+          "Parameter                   | Coefficient |        95% CI",
+          "---------------------------------------------------------",
+          "SD (Intercept: persons)     |        3.41 | [ 1.67, 6.93]",
+          "SD (xb: persons)            |        1.21 | [ 0.60, 2.44]",
+          "Cor (Intercept~xb: persons) |       -1.00 | [-1.00, 1.00]",
+          "SD (Residual)               |        1.00 |              ",
+          "", "# Random Effects (Zero-Inflated Model)", "", "Parameter                   | Coefficient |        95% CI",
+          "---------------------------------------------------------",
+          "SD (Intercept: persons)     |        2.74 | [ 1.16, 6.43]",
+          "SD (zg: persons)            |        1.57 | [ 0.64, 3.82]",
+          "Cor (Intercept~zg: persons) |        1.00 | [-1.00, 1.00]"
         )
       )
     })
@@ -539,21 +547,20 @@ if (.runThisTest &&
           "",
           "# Random Effects Variances",
           "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |      3.4056",
-          "SD (xb: persons)            |      1.2132",
-          "Cor (Intercept~xb: persons) |     -1.0000",
-          "SD (Residual)               |      1.0000",
+          "Parameter                   | Coefficient |              95% CI",
+          "---------------------------------------------------------------",
+          "SD (Intercept: persons)     |      3.4056 | [ 1.67398, 6.92858]",
+          "SD (xb: persons)            |      1.2132 | [ 0.60210, 2.44440]",
+          "Cor (Intercept~xb: persons) |     -1.0000 | [-1.00000, 1.00000]",
+          "SD (Residual)               |      1.0000 |                    ",
           "",
           "# Random Effects (Zero-Inflated Model)",
           "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |      2.7358",
-          "SD (zg: persons)            |      1.5683",
-          "Cor (Intercept~zg: persons) |      1.0000",
-          "SD (Residual)               |      1.0000"
+          "Parameter                   | Coefficient |              95% CI",
+          "---------------------------------------------------------------",
+          "SD (Intercept: persons)     |      2.7358 | [ 1.16473, 6.42622]",
+          "SD (zg: persons)            |      1.5683 | [ 0.64351, 3.82225]",
+          "Cor (Intercept~zg: persons) |      1.0000 | [-1.00000, 1.00000]"
         )
       )
 
@@ -578,31 +585,72 @@ if (.runThisTest &&
           "",
           "# Random Effects Variances",
           "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |      3.4056",
-          "SD (xb: persons)            |      1.2132",
-          "Cor (Intercept~xb: persons) |     -1.0000",
-          "SD (Residual)               |      1.0000",
-          "",
-          "# Random Effects (Zero-Inflated Model)",
-          "",
-          "Parameter                   | Coefficient",
-          "-----------------------------------------",
-          "SD (Intercept: persons)     |      2.7358",
-          "SD (zg: persons)            |      1.5683",
-          "Cor (Intercept~zg: persons) |      1.0000",
-          "SD (Residual)               |      1.0000"
+          "Parameter                   | Coefficient |              95% CI",
+          "---------------------------------------------------------------",
+          "SD (Intercept: persons)     |      3.4056 | [ 1.67398, 6.92858]",
+          "SD (xb: persons)            |      1.2132 | [ 0.60210, 2.44440]",
+          "Cor (Intercept~xb: persons) |     -1.0000 | [-1.00000, 1.00000]",
+          "SD (Residual)               |      1.0000 |                    ",
+          "", "# Random Effects (Zero-Inflated Model)", "", "Parameter                   | Coefficient |              95% CI",
+          "---------------------------------------------------------------",
+          "SD (Intercept: persons)     |      2.7358 | [ 1.16473, 6.42622]",
+          "SD (zg: persons)            |      1.5683 | [ 0.64351, 3.82225]",
+          "Cor (Intercept~zg: persons) |      1.0000 | [-1.00000, 1.00000]"
         )
       )
     })
+
+
+    # proper alignment of CIs ---------------------
+
+    model_pr <- tryCatch(
+      {
+        load(url("https://github.com/d-morrison/parameters/raw/glmmTMB/data/pressure_durations.RData"))
+        glmmTMB(
+          formula = n_samples ~ Surface + Side + Jaw + (1 | Participant / Session),
+          ziformula = ~ Surface + Side + Jaw + (1 | Participant / Session),
+          dispformula = ~1,
+          family = nbinom2(),
+          data = pressure_durations
+        )
+      },
+      error = function(e) {
+        NULL
+      }
+    )
+
+    if (!is.null(model_pr)) {
+      test_that("print-model_parameters glmmTMB CI alignment", {
+        mp <- model_parameters(model_pr, effects = "random", component = "all")
+        out <- utils::capture.output(print(mp))
+        expect_equal(
+          out,
+          c(
+            "# Random Effects: conditional",
+            "",
+            "Parameter                           | Coefficient |       95% CI",
+            "----------------------------------------------------------------",
+            "SD (Intercept: Session:Participant) |        0.27 | [0.08, 0.87]",
+            "SD (Intercept: Participant)         |        0.38 | [0.16, 0.92]",
+            "SD (Residual)                       |        2.06 | [1.30, 3.27]",
+            "",
+            "# Random Effects: zero_inflated",
+            "",
+            "Parameter                           | Coefficient |       95% CI",
+            "----------------------------------------------------------------",
+            "SD (Intercept: Session:Participant) |        0.69 | [0.40, 1.19]",
+            "SD (Intercept: Participant)         |        2.39 | [1.25, 4.57]"
+          )
+        )
+      })
+    }
   }
 
 
 
   test_that("model_parameters.mixed-all", {
     params <- model_parameters(m4, effects = "all")
-    expect_equal(c(nrow(params), ncol(params)), c(14, 12))
+    expect_equal(c(nrow(params), ncol(params)), c(13, 12))
     expect_equal(
       colnames(params),
       c(
@@ -615,8 +663,7 @@ if (.runThisTest &&
       c(
         "(Intercept)", "child", "camper1", "(Intercept)", "child",
         "camper1", "SD (Intercept)", "SD (xb)", "Cor (Intercept~xb: persons)",
-        "SD (Observations)", "SD (Intercept)", "SD (zg)", "Cor (Intercept~zg: persons)",
-        "SD (Observations)"
+        "SD (Observations)", "SD (Intercept)", "SD (zg)", "Cor (Intercept~zg: persons)"
       )
     )
     expect_equal(
@@ -625,14 +672,14 @@ if (.runThisTest &&
         "conditional", "conditional", "conditional", "zero_inflated",
         "zero_inflated", "zero_inflated", "conditional", "conditional",
         "conditional", "conditional", "zero_inflated", "zero_inflated",
-        "zero_inflated", "zero_inflated"
+        "zero_inflated"
       )
     )
     expect_equal(
       params$Coefficient,
       c(
         2.54713, -1.08747, 0.2723, 1.88964, 0.15712, -0.17007, 3.40563,
-        1.21316, -1, 1, 2.73583, 1.56833, 1, 1
+        1.21316, -1, 1, 2.73583, 1.56833, 1
       ),
       tolerance = 1e-2
     )
@@ -705,17 +752,16 @@ if (.runThisTest &&
         "",
         "# Random Effects Variances",
         "",
-        "Parameter               | Coefficient",
-        "-------------------------------------",
-        "SD (Intercept: persons) |        0.93",
-        "SD (Residual)           |        1.00",
+        "Parameter               | Coefficient |       95% CI",
+        "----------------------------------------------------",
+        "SD (Intercept: persons) |        0.93 | [0.46, 1.89]",
+        "SD (Residual)           |        1.00 |             ",
         "",
         "# Random Effects (Zero-Inflated Model)",
         "",
-        "Parameter               | Coefficient",
-        "-------------------------------------",
-        "SD (Intercept: persons) |        1.17",
-        "SD (Residual)           |        1.00"
+        "Parameter               | Coefficient |       95% CI",
+        "----------------------------------------------------",
+        "SD (Intercept: persons) |        1.17 | [0.54, 2.57]"
       )
     )
   })
