@@ -1,4 +1,4 @@
-if (require("testthat") && require("insight") && require("parameters") && require("multcomp")) {
+if (requiet("testthat") && requiet("insight") && requiet("parameters") && requiet("multcomp")) {
   set.seed(123)
   lmod <- lm(Fertility ~ ., data = swiss)
   model <- glht(
